Retrieves a paginated list of accounts that the current user can view or manage.
get_accounts(canvas, include = NULL, per_page = 100)A list of accounts retrieved from the Canvas LMS API.
A list containing the 'api_key' and 'base_url' for authentication.
A vector of additional information to include. Default is NULL.
Number of accounts to retrieve per page. Default is 100.