This function retrieves a paginated list of all courses visible in the public index using the Canvas LMS API. NOTE This function might take a while to finish.
get_all_courses(canvas, per_page = 100)A data frame of courses visible in the public index.
An object containing the Canvas API key and base URL, obtained through the canvas_authenticate function.
(Optional) The number of courses to retrieve per page of results (default is 100).