Learn R Programming

vvcanvas (version 0.0.8)

get_assignments: Get Assignments from Canvas LMS API

Description

Fetches a list of assignments within a specific course from the Canvas LMS API.

Usage

get_assignments(canvas, course_id)

Value

A list of assignments retrieved from the Canvas LMS API.

Arguments

canvas

A list containing the 'api_key' and 'base_url' for authentication.

course_id

The ID of the course for which to retrieve the assignments.