This function retrieves a list of announcements for a specific course in the Canvas LMS API.
get_course_announcements(canvas, course_id, per_page = 100)A data frame of course announcements.
An object containing the Canvas API key and base URL, obtained through the canvas_authenticate function.
The ID of the course for which to retrieve announcements.
(Optional) The number of announcements to retrieve per page of results (default is 100).