get_course_details: Get Course Details from Canvas LMS API
Description
Retrieves detailed information about a specific course from the Canvas LMS API.
Usage
get_course_details(canvas, course_id)
Value
A dataframe containing the detailed information about the course.
Arguments
- canvas
A list containing the 'api_key' and 'base_url' for authentication.
- course_id
The ID of the course for which to retrieve the details.