This function retrieves a list of folders for a specific course in the Canvas LMS API.
get_course_folders(canvas, course_id, per_page = 100)A data frame of course folders.
An object containing the Canvas API key and base URL, obtained through the canvas_authenticate function.
The ID of the course for which to retrieve folders.
Number of courses to retrieve per page. Default is 100.
Returns a list of all folders and sub folders for the given course. Note that for some reported sub folders its main folder may be outside of the course.
get_course_root_folder() and get_user_folders()