This function retrieves the pages within a specific course in the Canvas LMS API.
get_course_pages(canvas, course_id, per_page = 100)A list of pages within the specified course.
An object containing the Canvas API key and base URL, obtained through the canvas_authenticate function.
The ID of the course for which to fetch the pages.
(Optional) The number of pages to retrieve per page of results (default is 50).