Learn R Programming

vvcanvas (version 0.0.8)

get_course_participation: Get course-level participation data from Canvas LMS API

Description

Fetches the participation data for a specific course from the Canvas LMS API.

Usage

get_course_participation(canvas, course_id)

Value

The participation data for the specified course retrieved from the Canvas LMS API.

Arguments

canvas

A list containing the 'api_key' and 'base_url' for authentication.

course_id

The ID of the course for which to retrieve the participation data.