Retrieves the department-level participation data for a specific account and term from the Canvas LMS API.
get_department_participation_data(
canvas,
account_id,
type = "current",
term_id = NULL,
per_page = 100
)A data frame of participation data retrieved from the Canvas LMS API.
A list containing the 'api_key' and 'base_url' for authentication.
The ID of the account for which to retrieve the participation data.
The type of courses to include in the data. Can be 'current', 'completed', or 'term'.
The ID of the term for which to retrieve the participation data. Only used when type is 'terms/<term_id>'.
Number of participation data to retrieve per page. Default is 100.