Retrieves department-level statistics for a specific account and term from the Canvas LMS API.
get_department_statistics(canvas, account_id, type = "current", term_id = NULL)A list of department-level statistics retrieved from the Canvas LMS API.
A list containing the 'api_key' and 'base_url' for authentication.
The ID of the account for which to retrieve the statistics.
The type of courses to include in the data. Can be 'current', 'completed', or 'term'.
The ID of the term for which to retrieve the statistics. Only used when type is 'terms/<term_id>'.