Learn R Programming

vvcanvas (version 0.0.8)

get_group_categories: Get group categories for a context

Description

This function retrieves the group categories for a specific context (e.g., course) in the Canvas LMS API.

Usage

get_group_categories(canvas, course_id)

Value

A data frame of group categories in the specified context.

Arguments

canvas

A list containing the 'api_key' and 'base_url' for authentication.

course_id

The ID of the course for which to retrieve the group categories.