Learn R Programming

vvcanvas (version 0.0.8)

get_group_info: Get information about a single group

Description

This function retrieves information about a specific group in the Canvas LMS API.

Usage

get_group_info(canvas, group_id)

Value

A list containing the information about the specified group.

Arguments

canvas

A list containing the 'api_key' and 'base_url' for authentication.

group_id

The ID of the group for which to retrieve the information.