Learn R Programming

vvcanvas (version 0.0.8)

get_group_memberships: Get group memberships

Description

This function retrieves the memberships for a specific group in the Canvas LMS API.

Usage

get_group_memberships(canvas, group_id)

Value

A data frame of memberships in the specified group.

Arguments

canvas

A list containing the 'api_key' and 'base_url' for authentication.

group_id

The ID of the group for which to retrieve the memberships.