Learn R Programming

vvcanvas (version 0.0.8)

get_quiz_submissions: Retrieves quiz submissions.

Description

This function retrieves the submissions to a specific quiz in a specific course in the Canvas LMS API.

Usage

get_quiz_submissions(canvas, course_id, quiz_id)

Value

A data frame containing the submission data.

Arguments

canvas

An object containing the Canvas API key and base URL, obtained through the canvas_authenticate function.

course_id

The ID of the course for which to fetch submissions.

quiz_id

The ID of the quiz for which to fetch the submissions.

See Also

get_assignment_submissions()