Learn R Programming

vvcanvas (version 0.0.8)

get_roles: Retrieve Roles for a Canvas Account

Description

This function retrieves a paginated list of the roles available to a specific account in the Canvas LMS system.

Usage

get_roles(canvas, account_id, per_page = 100)

Value

A data frame containing the roles available to the specified account.

Arguments

canvas

A list containing the base URL and API key for the Canvas LMS instance.

account_id

The ID of the account for which you want to retrieve the roles.

per_page

The number of roles to retrieve per page (default is 100).