Learn R Programming

vvcanvas (version 0.0.8)

get_single_conversation: Retrieves a single conversation.

Description

This function retrieves all details concerning a specific conversation.

Usage

get_single_conversation(canvas, conversation_id)

Value

Returns information for a specific conversation for the current user. Response includes all fields that are present in the list/index action as well as messages and extended participant information.

Arguments

canvas

An object containing the Canvas API key and base URL, obtained through the canvas_authenticate function.

conversation_id

The id of the specific conversation.

See Also

get_conversations() and create_conversation().