Retrieves the student summaries for a specific course from the Canvas LMS API.
get_student_summaries(canvas, course_id, per_page = 100)A list of student summaries retrieved from the Canvas LMS API.
A list containing the 'api_key' and 'base_url' for authentication.
The ID of the course for which to retrieve the student summaries.
Number of student summaries to retrieve per page. Default is 100.