Learn R Programming

vvcanvas (version 0.0.8)

get_user_folders: Retrieves folders of the current user.

Description

This function retrieves all folders associated with the user accessing the API.

Usage

get_user_folders(canvas)

Value

Returns a data frame containing the details on the folders available to the user accessing the API.

Arguments

canvas

An object containing the Canvas API key and base URL, obtained through the canvas_authenticate function.

Details

Returns a list of all folders 'owned by' the current user. Note that since self replaces user_id, the id of the user accessing the API does not need to be specified. The highest level folder name is my folder.

See Also

get_course_root_folder() and get_course_folders()