This function retrieves a paginated list of all enrollment terms for a specified account in Canvas LMS.
list_all_enrollment_terms(canvas, account_id, per_page = 100)A dataframe containing all enrollment terms details
A list containing Canvas API configuration:
base_url: The base URL of your Canvas instance
api_key: Your Canvas API key
The ID of the account for which to retrieve enrollment terms
The number of terms to retrieve per page (default is 100)