Creates a new discussion topic in a specific course using the Canvas LMS API.
post_new_discussion(
canvas,
course_id,
discussion_title,
discussion_message,
discussion_is_announcement = FALSE
)A confirmation message that the discussion has been created.
A list containing the 'api_key' and 'base_url' for authentication.
The ID of the course in which to create the discussion.
The title of the discussion topic.
The initial message content of the discussion topic.
(Optional) Whether the discussion should be an announcement. Defaults to FALSE.