This function retrieves the submissions to a specific quiz in a specific course in the Canvas LMS API.
get_quiz_submissions(canvas, course_id, quiz_id)A data frame containing the submission data.
An object containing the Canvas API key and base URL, obtained through the
canvas_authenticate function.
The ID of the course for which to fetch submissions.
The ID of the quiz for which to fetch the submissions.
get_assignment_submissions()