This function retrieves a paginated list of the roles available to a specific account in the Canvas LMS system.
get_roles(canvas, account_id, per_page = 100)A data frame containing the roles available to the specified account.
A list containing the base URL and API key for the Canvas LMS instance.
The ID of the account for which you want to retrieve the roles.
The number of roles to retrieve per page (default is 100).