This function retrieves all details concerning a specific conversation.
get_single_conversation(canvas, conversation_id)Returns information for a specific conversation for the current user. Response includes all fields that are present in the list/index action as well as messages and extended participant information.
An object containing the Canvas API key and base URL, obtained through the
canvas_authenticate function.
The id of the specific conversation.
get_conversations() and create_conversation().