This function retrieves all folders associated with the user accessing the API.
get_user_folders(canvas)Returns a data frame containing the details on the folders available to the user accessing the API.
An object containing the Canvas API key and base URL, obtained through the
canvas_authenticate function.
Returns a list of all folders 'owned by' the current user. Note that since self replaces
user_id, the id of the user accessing the API does not need to be specified. The
highest level folder name is my folder.
get_course_root_folder() and get_course_folders()