Follows 'next' links in the Link header to retrieve all pages. Returns a list of all responses.
paginate(initial_response, access_token, showProgress = TRUE)A list of httr response objects, one for each page.
The initial httr response object from the first GET request.
The Canvas API access token (string).
Logical; whether to print progress as pages are fetched. Default is TRUE.